@@ -1,9 +1,10 @@
 use v5.20;
 use warnings;
-package Log::Dispatchouli::Proxy 3.009;
+package Log::Dispatchouli::Proxy 3.010;
 # ABSTRACT: a simple wrapper around Log::Dispatch
 
-use experimental 'postderef'; # Not dangerous.  Is accepted without changed.
+# Not dangerous.  Accepted without change.
+use experimental 'postderef', 'signatures';
 
 use Log::Fmt ();
 use Params::Util qw(_ARRAY0 _HASH0);
@@ -29,9 +30,7 @@ use Params::Util qw(_ARRAY0 _HASH0);
 #pod
 #pod =cut
 
-sub _new {
-  my ($class, $arg) = @_;
-
+sub _new ($class, $arg) {
   my $guts = {
     parent => $arg->{parent},
     logger => $arg->{logger},
@@ -43,8 +42,7 @@ sub _new {
   bless $guts => $class;
 }
 
-sub proxy  {
-  my ($self, $arg) = @_;
+sub proxy ($self, $arg) {
   $arg ||= {};
 
   my @proxy_ctx;
@@ -101,9 +99,7 @@ sub get_muted {
   return $_[0]->parent->get_muted;
 }
 
-sub _get_all_prefix {
-  my ($self, $arg) = @_;
-
+sub _get_all_prefix ($self, $arg) {
   return [
     $self->{proxy_prefix},
     $self->get_prefix,
@@ -111,8 +107,14 @@ sub _get_all_prefix {
   ];
 }
 
-sub log {
-  my ($self, @rest) = @_;
+sub flog_messages ($self, @rest) {
+  my $arg = _HASH0($rest[0]) ? shift(@rest) : {};
+  local $arg->{prefix} = $self->_get_all_prefix($arg);
+
+  $self->parent->flog_messages($arg, @rest);
+}
+
+sub log ($self, @rest) {
   my $arg = _HASH0($rest[0]) ? shift(@rest) : {};
 
   return if $self->_get_local_muted and ! $arg->{fatal};
@@ -122,18 +124,14 @@ sub log {
   $self->parent->log($arg, @rest);
 }
 
-sub log_fatal {
-  my ($self, @rest) = @_;
-
+sub log_fatal ($self, @rest) {
   my $arg = _HASH0($rest[0]) ? shift(@rest) : {};
   local $arg->{fatal}  = 1;
 
   $self->log($arg, @rest);
 }
 
-sub log_debug {
-  my ($self, @rest) = @_;
-
+sub log_debug ($self, @rest) {
   my $debug = $self->get_debug;
   return if defined $debug and ! $debug;
 
@@ -143,9 +141,7 @@ sub log_debug {
   $self->log($arg, @rest);
 }
 
-sub _compute_proxy_ctx_kvstr_aref {
-  my ($self) = @_;
-
+sub _compute_proxy_ctx_kvstr_aref ($self) {
   return $self->{proxy_ctx_kvstr} //= do {
     my @kvstr = $self->parent->_compute_proxy_ctx_kvstr_aref->@*;
 
@@ -158,21 +154,29 @@ sub _compute_proxy_ctx_kvstr_aref {
   };
 }
 
-sub log_event {
-  my ($self, $event, $data) = @_;
+sub fmt_event ($self, $type, $data) {
+  my $kv_aref = Log::Fmt->_pairs_to_kvstr_aref([
+    event => $type,
+    (_ARRAY0($data) ? @$data : $data->%{ sort keys %$data })
+  ]);
 
+  splice @$kv_aref, 1, 0, $self->_compute_proxy_ctx_kvstr_aref->@*;
+
+  return join q{ }, @$kv_aref;
+}
+
+sub log_event ($self, $event, $data) {
   return if $self->get_muted;
 
+  my $message = $self->fmt_event($event, $data);
 
-  my $message = $self->logger->_log_event($event,
-    $self->_compute_proxy_ctx_kvstr_aref,
-    [ _ARRAY0($data) ? @$data : $data->%{ sort keys %$data } ]
+  $self->logger->dispatcher->log(
+    level   => 'info',
+    message => $message,
   );
 }
 
-sub log_debug_event {
-  my ($self, $event, $data) = @_;
-
+sub log_debug_event ($self, $event, $data) {
   return unless $self->get_debug;
 
   return $self->log_event($event, $data);
@@ -201,7 +205,7 @@ Log::Dispatchouli::Proxy - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 3.009
+version 3.010
 
 =head1 DESCRIPTION
 
